@@ -325,7 +325,7 @@ for (i in 1:100) {
   ld1 <- d1(x=x, mean=m, sigma=Sigma)
   ld2 <- d2(x=x, mean=m, sigma=Sigma)
 
-  stopifnot(all.equal(ld1, ld2))
+  stopifnot(all.equal(ld1, ld2, tol = .Machine$double.eps^(1/3)))
 }
 
 ### --- Singular Sigma --- Now treated the same as  dnorm(*, sd=0):  "Inf or 0"
